@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9406';
+$XML::MyXML::VERSION = '0.9407';
 use strict;
 use warnings;
 use Carp;
@@ -473,7 +473,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9406';
+$XML::MyXML::Object::VERSION = '0.9407';
 use Carp;
 use Encode;
 use Scalar::Util qw/ weaken /;
@@ -599,6 +599,29 @@ sub text {
 *value = \&text;
 
 
+sub inner_xml {
+	my $self = shift;
+	my $flags = (@_ and ref $_[-1]) ? pop() : {};
+	my $set_xml = @_ ? defined $_[0] ? shift() : '' : undef;
+
+	if (! defined $set_xml) {
+		my $xml = $self->to_xml($flags);
+		$xml =~ s/\A\<.*?\>//s;
+		$xml =~ s/\<\/[^\>]*\>\z//s;
+		return $xml;
+	} else {
+		my $xml = "<div>$set_xml</div>";
+		my $obj = XML::MyXML::xml_to_object($xml, $flags);
+		$self->{content} = [];
+		foreach my $child (@{ $obj->{content} || [] }) {
+			$child->{parent} = $self;
+			weaken( $child->{parent} );
+			push @{ $self->{content} }, $child;
+		}
+	}
+}
+
+
 sub attr {
 	my $self = shift;
 	my $attrname = shift;
@@ -702,7 +725,6 @@ sub to_tidy_xml {
 
 
 
-
 1; # End of XML::MyXML
 
 __END__
@@ -717,7 +739,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9406
+version 0.9407
 
 =head1 SYNOPSIS
 
@@ -889,6 +911,12 @@ If provided a set_value, will delete all contents of $obj and will place C<set_v
 
 Optional flags: C<strip>
 
+=head2 $obj->inner_xml([xml_string])
+
+Gets or sets the inner XML of the $obj node, depending on whether C<xml_string> is provided.
+
+Optional flags: C<bytes>
+
 =head2 $obj->attr('attrname' [, 'attrvalue'])
 
 Gets/Sets the value of the 'attrname' attribute of the top element. Returns undef if attribute does not exist. If called without the 'attrname' paramter, returns a hash with all attribute => value pairs. If setting with an attrvalue of C<undef>, then removes that attribute entirely.
